@@ -34,6 +34,8 @@ __all__ = (
     "TypeType",
     "VendorNameType",
     "ServiceName",
+    "PaginatorName",
+    "WaiterName",
 )
 
 
@@ -347,3 +349,5 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal["list_repository_associations"]
+WaiterName = Literal["code_review_completed", "repository_association_succeeded"]
